﻿// 
// Copyright (c) 2013-2016 Carsten Sonne Larsen <cs@innolan.dk>
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;
using Ntp.Common.Log;

namespace Ntp.Analyzer.Data.Log
{
    internal static class LogMessages
    {
        internal const string DatabaseCacheError = "Mapper does not implement caching.";
        internal const string DatabaseNoUpdate = "Updating rows in {0} table is not supported.";
    }

    internal static class LogExtensions
    {
        internal static void CreateDatabaseError(this LogBase log, Exception e)
        {
            log.WriteLine("Failed to create database.", Severity.Error);
            log.WriteLine(e, Severity.Trace);
        }

        internal static void CreateTable(this LogBase log, string table)
        {
            log.WriteLine(
                $"Creating new table '{table}'.",
                Severity.Notice);
        }

        internal static void CreateTableError(this LogBase log, Exception e)
        {
            log.WriteLine("Could not create database table.", Severity.Error);
            log.WriteLine(e, Severity.Trace);
        }

        internal static void DeleteError(this LogBase log, string table, Exception e)
        {
            log.WriteLine($"Error while deleting from table {table}: {e.Message}", Severity.Error);
            log.WriteLine(e, Severity.Trace);
        }

        internal static void InsertError(this LogBase log, string table, Exception e)
        {
            log.WriteLine($"Error while inserting into table {table}: {e.Message}", Severity.Error);
            log.WriteLine(e, Severity.Trace);
        }

        internal static void ReadError(this LogBase log, string table, Exception e)
        {
            log.WriteLine($"Error while reading from table {table}: {e.Message}", Severity.Error);
            log.WriteLine(e, Severity.Trace);
        }

        internal static void TableExists(this LogBase log, string table)
        {
            log.WriteLine(
                $"Table '{table}' already exist.",
                Severity.Debug);
        }

        internal static void UpdateError(this LogBase log, string table, Exception e)
        {
            log.WriteLine($"Error while updating table {table}: {e.Message}", Severity.Error);
            log.WriteLine(e, Severity.Trace);
        }
    }
}